@@ -20,13 +20,12 @@
 #ifndef KDED_H
 #define KDED_H
 
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QTimer>
-#include <QtCore/QHash>
-#include <QtCore/QSet>
+#include <QObject>
+#include <QString>
+#include <QTimer>
+#include <QHash>
+#include <QSet>
 
-#include <QDBusConnection>
 #include <QDBusAbstractAdaptor>
 
 #include <ksycoca.h>
@@ -71,6 +70,7 @@ public:
     void unregisterWindowId(qlonglong windowId, const QString &sender);
     //@}
     void recreate(bool initial);
+    // TODO KF6 remove
     void loadSecondPhase();
 
     //@{
@@ -230,7 +230,7 @@ public:
 public Q_SLOTS:
     void recreate();
     bool isTestModeEnabled();
-    void enableTestMode();
+    void setTestModeEnabled();
 };
 
 class KUpdateD : public QObject
